searchData={"items":[{"type":"module","title":"Ollama","doc":"![License](https://img.shields.io/github/license/lebrunel/ollama-ex?color=informational)\n\n[Ollama](https://ollama.ai) is a nifty little tool for running large language\nmodels locally, and this is a nifty little library for working with Ollama in\nElixir.","ref":"Ollama.html"},{"type":"module","title":"Highlights - Ollama","doc":"- API client fully implementing the Ollama API - `Ollama.API`\n- Server module implementing OpenAI compatible completion and chat endpoints,\nproxying through to Ollama - *COMING SOON*","ref":"Ollama.html#module-highlights"},{"type":"module","title":"Installation - Ollama","doc":"The package can be installed by adding `ollama` to your list of dependencies\nin `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:ollama, \"~> 0.1\"}\n  ]\nend\n```","ref":"Ollama.html#module-installation"},{"type":"module","title":"Ollama.API","doc":"Client module for interacting with the Ollama API.\n\nCurrently supporting all Ollama API endpoints except pushing models (`/api/push`),\nwhich is coming soon.","ref":"Ollama.API.html"},{"type":"module","title":"Usage - Ollama.API","doc":"Assuming you have Ollama running on localhost, and that you have installed a\nmodel, immediately trying the `completion/4` and `chat/4` functions should be very\nstraightforward.\n\n    iex> api = Ollama.API.new\n    iex> Ollama.API.completion(api, \"llama2\", \"Why is the sky blue?\")\n    {:ok, %{\"response\" => \"The sky is blue because it is the color of the sky.\"}}","ref":"Ollama.API.html#module-usage"},{"type":"function","title":"Ollama.API.chat/4","doc":"Generates the next message in a chat using the specified model. Optionally\nstreamable.","ref":"Ollama.API.html#chat/4"},{"type":"function","title":"Message structure - Ollama.API.chat/4","doc":"A list of chat messages must be passed to this request. Each message has the\nfollowing fields:\n\n- `role` - The role of the message, either `system`, `user` or `assistant`.\n- `content` - The content of the message.\n- `images` - *(optional)* List of Base64 encoded images (for multimodal models only).","ref":"Ollama.API.html#chat/4-message-structure"},{"type":"function","title":"Options - Ollama.API.chat/4","doc":"The following options are accepted:\n\n- `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values)\n- `:template` - Prompt template, overriding the model default\n- `:stream` - A callback to handle streaming response chunks.","ref":"Ollama.API.html#chat/4-options"},{"type":"function","title":"Examples - Ollama.API.chat/4","doc":"iex> messages = [\n    ...>   %{role: \"system\", content: \"You are a helpful assistant.\"},\n    ...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n    ...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n    ...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n    ...> ]\n\n    # Passing a callback to the :stream option initiates a streaming request.\n    iex> Ollama.API.chat(api, \"llama2\", messages, stream: fn data ->\n    ...>   IO.inspect(data) # %{\"message\" => %{\"role\" => \"assistant\", \"content\" => \"Mie\"}}\n    ...> end)\n    {:ok, \"\"}\n\n    # Without the :stream option initiates a standard request\n    iex> Ollama.API.chat(api, \"llama2\", messages)\n    {:ok, %{\"message\" => %{\n      \"role\" => \"assistant\",\n      \"content\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n    }, ...}}","ref":"Ollama.API.html#chat/4-examples"},{"type":"function","title":"Ollama.API.check_blob/2","doc":"Checks a blob exists in ollama by its digest or binary data.","ref":"Ollama.API.html#check_blob/2"},{"type":"function","title":"Examples - Ollama.API.check_blob/2","doc":"iex> Ollama.API.check_blob(api, \"sha256:fe938a131f40e6f6d40083c9f0f430a515233eb2edaa6d72eb85c50d64f2300e\")\n    {:ok, true}\n\n    iex> Ollama.API.check_blob(api, \"this should not exist\")\n    {:ok, false}","ref":"Ollama.API.html#check_blob/2-examples"},{"type":"function","title":"Ollama.API.completion/4","doc":"Generates a completion for the given prompt using the specified model.\nOptionally streamable.","ref":"Ollama.API.html#completion/4"},{"type":"function","title":"Options - Ollama.API.completion/4","doc":"The following options are accepted:\n\n- `:images` - A list of Base64 encoded images to be included with the prompt (for multimodal models only).\n- `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).\n- `:system` - System prompt, overriding the model default.\n- `:template` - Prompt template, overriding the model default.\n- `:context` - The context parameter returned from a previous `f:completion/4` call (enabling short conversational memory).\n- `:stream` - A callback to handle streaming response chunks.","ref":"Ollama.API.html#completion/4-options"},{"type":"function","title":"Examples - Ollama.API.completion/4","doc":"# Passing a callback to the :stream option initiates a streaming request.\n    iex> Ollama.API.completion(api, \"llama2\", \"Why is the sky blue?\", stream: fn data ->\n    ...>   IO.inspect(data) # %{\"response\" => \"The\"}\n    ...> end)\n    {:ok, \"\"}\n\n    # Without the :stream option initiates a standard request\n    iex> Ollama.API.completion(api, \"llama2\", \"Why is the sky blue?\")\n    {:ok, %{\"response\": \"The sky is blue because it is the color of the sky.\", ...}}","ref":"Ollama.API.html#completion/4-examples"},{"type":"function","title":"Ollama.API.copy_model/3","doc":"Creates a model with another name from an existing model.","ref":"Ollama.API.html#copy_model/3"},{"type":"function","title":"Example - Ollama.API.copy_model/3","doc":"iex> Ollama.API.copy_model(api, \"llama2\", \"llama2-backup\")\n    {:ok, true}","ref":"Ollama.API.html#copy_model/3-example"},{"type":"function","title":"Ollama.API.create_blob/2","doc":"Creates a blob from its binary data.","ref":"Ollama.API.html#create_blob/2"},{"type":"function","title":"Example - Ollama.API.create_blob/2","doc":"iex> Ollama.API.create_blob(api, modelfile)\n    {:ok, true}","ref":"Ollama.API.html#create_blob/2-example"},{"type":"function","title":"Ollama.API.create_model/4","doc":"Creates a model using the given name and model file. Optionally\nstreamable.\n\nAny dependent blobs reference in the modelfile, such as `FROM` and `ADAPTER`\ninstructions, must exist first. See `check_blob/2` and `create_blob/2`.","ref":"Ollama.API.html#create_model/4"},{"type":"function","title":"Options - Ollama.API.create_model/4","doc":"The following options are accepted:\n\n- `:stream` - A callback to handle streaming response chunks.","ref":"Ollama.API.html#create_model/4-options"},{"type":"function","title":"Example - Ollama.API.create_model/4","doc":"iex> modelfile = \"FROM llama2\\nSYSTEM \\\"You are mario from Super Mario Bros.\\\"\"\n    iex> Ollama.API.create_model(api, \"mario\", modelfile, stream: fn data ->\n    ...>   IO.inspect(data) # %{\"status\" => \"reading model metadata\"}\n    ...> end)\n    {:ok, \"\"}","ref":"Ollama.API.html#create_model/4-example"},{"type":"function","title":"Ollama.API.delete_model/2","doc":"Deletes a model and its data.","ref":"Ollama.API.html#delete_model/2"},{"type":"function","title":"Example - Ollama.API.delete_model/2","doc":"iex> Ollama.API.delete_model(api, \"llama2\")\n    {:ok, true}","ref":"Ollama.API.html#delete_model/2-example"},{"type":"function","title":"Ollama.API.embeddings/4","doc":"Generate embeddings from a model for the given prompt.","ref":"Ollama.API.html#embeddings/4"},{"type":"function","title":"Example - Ollama.API.embeddings/4","doc":"iex> Ollama.API.embeddings(api, \"llama2\", \"Here is an article about llamas...\")\n    {:ok, %{\"embedding\" => [\n      0.5670403838157654, 0.009260174818336964, 0.23178744316101074, -0.2916173040866852, -0.8924556970596313,\n      0.8785552978515625, -0.34576427936553955, 0.5742510557174683, -0.04222835972905159, -0.137906014919281\n    ]}}","ref":"Ollama.API.html#embeddings/4-example"},{"type":"function","title":"Ollama.API.list_models/1","doc":"Lists all models that Ollama has available.","ref":"Ollama.API.html#list_models/1"},{"type":"function","title":"Example - Ollama.API.list_models/1","doc":"iex> Ollama.API.list_models(api)\n    {:ok, %{\"models\" => [\n      %{\"name\" => \"codellama:13b\", ...},\n      %{\"name\" => \"llama2:latest\", ...},\n    ]}}","ref":"Ollama.API.html#list_models/1-example"},{"type":"function","title":"Ollama.API.new/1","doc":"Creates a new API client with the provided URL. If no URL is given, it\ndefaults to `\"http://localhost:11434/api\"`.","ref":"Ollama.API.html#new/1"},{"type":"function","title":"Examples - Ollama.API.new/1","doc":"iex> api = Ollama.API.new(\"https://ollama.service.ai:11434\")\n    %Ollama.API{}","ref":"Ollama.API.html#new/1-examples"},{"type":"function","title":"Ollama.API.pull_model/3","doc":"Downloads a model from the ollama library. Optionally streamable.","ref":"Ollama.API.html#pull_model/3"},{"type":"function","title":"Options - Ollama.API.pull_model/3","doc":"The following options are accepted:\n\n- `:stream` - A callback to handle streaming response chunks.","ref":"Ollama.API.html#pull_model/3-options"},{"type":"function","title":"Example - Ollama.API.pull_model/3","doc":"iex> Ollama.API.pull_model(api, \"llama2\", stream: fn data ->\n    ...>   IO.inspect(data) # %{\"status\" => \"pulling manifest\"}\n    ...> end)\n    {:ok, \"\"}","ref":"Ollama.API.html#pull_model/3-example"},{"type":"function","title":"Ollama.API.show_model/2","doc":"Shows all information for a specific model.","ref":"Ollama.API.html#show_model/2"},{"type":"function","title":"Example - Ollama.API.show_model/2","doc":"iex> Ollama.API.show_model(api, \"llama2\")\n    {:ok, %{\n      \"details\" => %{\n        \"families\" => [\"llama\", \"clip\"],\n        \"family\" => \"llama\",\n        \"format\" => \"gguf\",\n        \"parameter_size\" => \"7B\",\n        \"quantization_level\" => \"Q4_0\"\n      },\n      \"modelfile\" => \"...\",\n      \"parameters\" => \"...\",\n      \"template\" => \"...\"\n    }}","ref":"Ollama.API.html#show_model/2-example"},{"type":"type","title":"Ollama.API.handle_stream/0","doc":"Stream handler callback function","ref":"Ollama.API.html#t:handle_stream/0"},{"type":"type","title":"Ollama.API.message/0","doc":"Chat message\n\nA chat message is a `t:map/0` with the following fields:\n\n- `role` - The role of the message, either `system`, `user` or `assistant`.\n- `content` - The content of the message.\n- `images` - *(optional)* List of Base64 encoded images (for multimodal models only).","ref":"Ollama.API.html#t:message/0"},{"type":"type","title":"Ollama.API.model/0","doc":"Model name, in the format ` : `","ref":"Ollama.API.html#t:model/0"},{"type":"type","title":"Ollama.API.response/0","doc":"API function response","ref":"Ollama.API.html#t:response/0"},{"type":"type","title":"Ollama.API.t/0","doc":"Client struct","ref":"Ollama.API.html#t:t/0"},{"type":"module","title":"Ollama.Blob","doc":"Module for working for blobs in Ollama.\n\nCurrently this module only provides a function for generating a SHA256 digest\nof a binary blob.","ref":"Ollama.Blob.html"},{"type":"function","title":"Ollama.Blob.digest/1","doc":"Generates a SHA256 digest of a binary blob.","ref":"Ollama.Blob.html#digest/1"},{"type":"function","title":"Example - Ollama.Blob.digest/1","doc":"iex> Ollama.Blob.digest(\"hello\")\n    \"sha256:2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b9824\"","ref":"Ollama.Blob.html#digest/1-example"},{"type":"type","title":"Ollama.Blob.digest/0","doc":"Blob digest\n\nThe digest is a hex-encoded SHA256 hash of the binary blob, prefixed with the\nalgorithm.","ref":"Ollama.Blob.html#t:digest/0"},{"type":"type","title":"Example - Ollama.Blob.digest/0","doc":"\"sha256:054edec1d0211f624fed0cbca9d4f9400b0e491c43742af2c5b0abebf0c990d8\"","ref":"Ollama.Blob.html#t:digest/0-example"}],"content_type":"text/markdown"}